@@ -15,8 +15,16 @@ if TYPE_CHECKING:  # pragma: no cover
     "generic.time.NegateRule",
     "generic.time.EitherRule",
     "generic.time.BothRule",
+    "generic.time.NANDRule",
+    "generic.time.NeitherRule",
+    "generic.time.XORRule",
+    "generic.time.XNORRule",
+    "generic.time.ImpliesRule",
     "generic.time.ResolveAtTime",
     "generic.value.ResolveToValue",
+    "generic.value.AdditiveRule",
+    "generic.value.MultiplicitiveRule",
+    "generic.value.ModulusRule",
     "generic.value.ResolveRandomSeed",
     "generic.value.ResolveRandomIndex",
     "generic.value.ResolveMultipleValues",
